%
%  This script reads in the files produced by the radiative-convective
%  model and displays the results
%-------------------------------------------------------------------------
nc=25;  % Number of contours for Time-Height sections
%-------------------------------------------------------------------------
file=input('Enter subdirectory name (default = output)','s');
if isempty(file)
   file='output';
end
%
%   Load output files
%
load(strcat(file,filesep,'time.out'))
load(strcat(file,filesep,'profile.out'))
load(strcat(file,filesep,'cldhov.out'))
load(strcat(file,filesep,'thov.out'))
load(strcat(file,filesep,'qhov.out'))
load(strcat(file,filesep,'rhhov.out'))
load(strcat(file,filesep,'mhov.out'))
load(strcat(file,filesep,'mdhov.out'))
load(strcat(file,filesep,'mphov.out'))
%load(strcat(file,filesep,'buoy.out'))
load(strcat(file,filesep,'omhov.out'))
if exist(strcat(file,filesep,'coolhov.out'),'file')
    load(strcat(file,filesep,'coolhov.out'))
end    
if exist(strcat(file,filesep,'conhov.out'),'file')
    load(strcat(file,filesep,'conhov.out'))
end    
%
%  Pressure and time vectors
%
p=profile(:,1);
time1=time(:,1);
timem=time(:,12);
%
%  Calculate altitude from hydrostatic equation
%
tk=profile(:,2)+273.15;
qm=0.001.*profile(:,3);
tv=tk.*(1+0.608.*qm);
qp=max(size(p));
z=zeros(1,qp);
for i=2:qp
    z(i)=z(i-1)+(287./9.81).*0.5.*(tv(i)+tv(i-1)).*log(p(i-1)./p(i));
end
zkm=0.001.*z;
%
% Display fields using menus
%
%  First menu offers choice among time series, profiles, and time-height
%  sections
%
i=1;
while i > 0
    imenu=menu('Main Menu','Time Series','Vertical Profiles','Time-Height Sections','Stop');
    if imenu == 4
        break
    end
    %
    % Next menu pertains to time series
    %
    if imenu == 1
        x=timem;
        j=1;
        while j > 0
            clear M
            M='off';
            jmenu=menu('Time Series','Precipitation and Evaporation', ...
                'Surface air and sea surface temperatures', ...
                '500 hPa Temperature and specific humidity', ...
                'Top of atmos. shortwave and longwave fluxes', ...
                'Surface fluxes', ...
                'Tropical cyclone potential intensity','Back to main menu');
            if jmenu == 7
                break
            end
            clear y2
            if jmenu == 1 
                y=time(:,2);
                y2=time(:,3);
                yl='Precipitation and Evaporation (mm/day)';
                M={'Precipitation';'Evaporation'};
            elseif jmenu == 2    
                y=time(:,5);
                y2=time(:,4);
                yl='SST and Lowest Level Air Temperature (C)';
                M={'SST';'Air temperature'};
            elseif jmenu == 3    
                y=time(:,6);
                y2=time(:,7);
                yl='500 mb T (C) and q (g/Kg)';
                M={'Temperature';'Specific Humidity'};
            elseif jmenu == 4    
                y=time(:,8);
                y2=time(:,9);
                yl='TOA Shortwave and Longwave (W/m^2)';
                M={'Shortwave';'Longwave'};
            elseif jmenu == 5    
                y=time(:,14)+time(:,15);
                y2=time(:,16)+time(:,17);
                yl='Surface Fluxes (W/m^2)';
                M={'Surface Radiative Flux';'Surface Turbulent Enthalpy Flux'};
            elseif jmenu == 6    
                y=time(:,10);
                yl='V_{max} (m/s)';
            end
            if exist('y2','var')
                h=plot(x,y,'b',x,y2,'r','linewidth',2);
            else
                h=plot(x,y,'linewidth',2);
            end    
            xlabel('Time (days)','fontweight','bold')  
            ylabel(yl,'fontweight','bold')  
            set(gca,'fontweight','bold')
            legend(M,'location','best')       
        end
    %
    % Next menu pertains to vertical profiles
    %       
    elseif imenu == 2
        zswitch=menu('Vertical axis','z','p');
        if zswitch == 1
            y=0.001.*z;
        else
            y=p;
        end    
        j=1;
        while j > 0
            clear x2 x3 x4 M
            M='off';
            jmenu=menu('Vertical Profiles', ...
                'Temperature',...
                'Skew-Tv-log-p',...
                'Buoyancy of parcel lifted from lowest layer',...
                'Relative humidity',...
                'Heating rates',...
                'Convective mass fluxes',...
                'Convective entrainment and detrainment',...
                'Moist static energy',...
                'Cloud fraction',...
                'Cloud water concentration','Go back');
           if jmenu == 11
               break
           end    
           clear x x2 x3 x4 
           if jmenu == 1
               x=profile(:,2);
               %qv=0.001*profile(:,3);
               %x=(273.15+x).*(1+qv/0.622)./(1+qv);
               xl='Temperature (C)';
           elseif jmenu == 2
               clf
               success=skewtv(p,profile(:,2),0.001*profile(:,3));
               %x=profile(:,3);
               %xl='Specific Humidity (gm/Kg)';
           elseif jmenu == 3
               x=profile(:,4);
               xl='Buoyancy (C)';
               %{
               [ x, x2 ] = thetaBv(p',profile(:,2)',profile(:,3)');
               x(end+1:qp)=NaN;
               x2(end+1:qp)=NaN;
               xl='\theta_B';
               %}
           elseif jmenu == 4
               x=100.*profile(:,5);
               x=min(x,100);
               xl='Relative Humidity (%)';
           elseif jmenu == 5
               x=profile(:,6);
               x2=profile(:,7);
               x3=profile(:,8);
               x4=profile(:,9);
               xl='Heating (C/day)';
               M={'Convective';'Radiative';'Turbulent';'Large-scale adiabatic'};
           elseif jmenu == 6
               x=profile(:,10);
               x2=profile(:,11);
               x3=profile(:,12);
               xl='Mass flux (10^{-3} Kg m^{-2} s^{-1})';
               M={'Net upward';'Penetrative';'Unsaturated'};
           elseif jmenu == 7
               x=profile(:,13);
               x2=profile(:,14);
               xl='Entrainment and Detrainment (10^{-3} Kg m^{-2} s^{-1})';
               M={'Entrainment';'Detrainment'};
           elseif jmenu == 8
               x=profile(:,15);
               x=min(x,x(1)+20);
               TA=profile(:,2);
               qa=0.001.*profile(:,3);
               es=6.112.*exp(17.67.*TA./(243.5+TA));
               qs=0.622.*es./(p-es);
               alv=2.5e6-630.*TA;
               x2=profile(:,15)+alv.*(qs-qa)./1005.7;
               x2=min(x2,x(1)+20);
               xd=profile(:,15)-alv.*qa/1005.7;
               xl='Moist Static Energy, Saturation Moist Static Energy (K)';
               M={'Moist Static Energy';'Saturation Moist Static Energy'};
           elseif jmenu == 9
               x=profile(:,16);
               xl='Cloud Fraction';
           elseif jmenu == 10
               x=profile(:,17);
               xl='Cloud Condensed Water (g/Kg)';
           end    
           if jmenu ~= 2
               if exist('x4','var')
                   h=plot(x,y,x2,y,x3,y,x4,y,'linewidth',2);
               elseif exist('x3','var') && exist('x4','var') == 0
                   h=plot(x,y,x2,y,x3,y,'linewidth',2);
               elseif exist('x2','var') && exist('x4','var') == 0 && exist('x3','var') == 0 
                   h=plot(x,y,x2,y,'linewidth',2);
               else
                   h=plot(x,y,'linewidth',2);
               end
               xlabel(xl,'fontweight','bold')
               if zswitch == 2
                   set(gca,'ydir','reverse')
                   ylabel('Pressure (mb)','fontweight','bold')
               else
                   set(gca,'ylim',[0 25])
                   ylabel('Altitude (km)','fontweight','bold')
               end
               set(gca,'fontweight','bold')
               legend(M,'location','best')
           end
        end    
    elseif imenu == 3
        zswitch=menu('Vertical axis','z','p');
        if zswitch == 1
            y=0.001.*z;
        else
            y=p;
        end    
        tswitch=menu('Options','Full Field','Difference from Initial State', ...
            'Difference from Final State');
        j=1;
        while j > 0
            jmenu=menu('Time-Height Sections', ...
            'Temperature', ...
            'Specific humidity', ...
            'Relative humidity', ...
            'Buoyancy of parcel lifted from lowest layer', ...
            'Cloud fraction', ...
            'Updraft convective mass flux', ...
            'Penetrative convective downdraft mass flux', ...
            'Unsaturated convective downdraft mass flux', ...
            'Net convective upward mass flux', ...
            'Omega', ...
            'Radiative Heating', ...
            'Convective Heating', ...
            'Radiative + Convective Heating', 'Go Back');
            if jmenu == 14
                break
            end
            if jmenu == 1
                f=transpose(thov);
                ftit='Temperature (K)';
            elseif jmenu == 2   
                f=transpose(qhov);
                ftit='Specific Humidity (gm/Kg)';
            elseif jmenu == 3   
                f=transpose(rhhov);
                ftit='Relative Humidity (%)';
            elseif jmenu == 4
                f=max(buoy,-0.1);
                [ntemp,mtemp]=size(f);
                if ntemp > mtemp
                    f=transpose(f);
                end                
                ftit='Lifted Parcel Buoyancy (K)';
            elseif jmenu == 5   
                f=transpose(cldhov);
                ftit='Cloud Fraction';
            elseif jmenu == 6   
                f=transpose(mhov);
                ftit='Upward Convective Mass Flux (10^{-3} Kg m^{-2} s^{-1})';
            elseif jmenu == 7   
                f=transpose(mdhov);
                ftit='Penetrative Downdraft Convective Mass Flux (10^{-3} Kg m^{-2} s^{-1})';
            elseif jmenu == 8   
                f=transpose(mphov);
                ftit='Unstaturated Downdraft Convective Mass Flux (10^{-3} Kg m^{-2} s^{-1})';
            elseif jmenu == 9   
                f=transpose(mhov+mdhov+mphov);
                ftit='Net Upward Convective Mass Flux (10^{-3} Kg m^{-2} s^{-1})';
            elseif jmenu == 10   
                f=transpose(omhov);
                ftit='Omega (hPa hr^{-1})';
            elseif jmenu == 11   
                f=transpose(coolhov);
                ftit='Radiative Heating (K day^{-1})';
            elseif jmenu == 12   
                f=transpose(conhov);
                ftit='Convective Heating (K day^{-1})';
            elseif jmenu == 13   
                f=transpose(coolhov+conhov);
                ftit='Radiative + Convective Heating (K day^{-1})';
            end
            %
            % Subtract initial or final states
            %
            [~,n]=size(f);
            ftemp=f;
            clear f0
            if tswitch == 1 
                f0=0;
            elseif tswitch == 2
                f0=f(:,1);
                %f0=fbak;
            elseif tswitch == 3
                f0=f(:,n);
            end    
            for j=1:n
                ftemp(:,j)=f(:,j)-f0;
            end
            f=ftemp; 
            %
            contourf(timem,y,f,nc);
            if tswitch > 1
                colormap(bluewhitered)
            else
                colormap(jet)
            end    
            xlabel('Time (days)','fontweight','bold')
            if zswitch == 2
                set(gca,'ydir','reverse')
                ylabel('Pressure (mb)','fontweight','bold')
            else
                set(gca,'ylim',[0 25])
                ylabel('Altitude (km)','fontweight','bold')
            end
            set(gca,'fontweight','bold')
            title(ftit,'fontweight','bold')
            kk=colorbar;
            set(kk,'fontweight','bold')
        end         
    end        
end    